// This file was generated by ecm_setup_version(): DO NOT EDIT!

#ifndef KMBOX_VERSION_H
#define KMBOX_VERSION_H

#define KMBOX_VERSION_STRING "6.4.0"
#define KMBOX_VERSION_MAJOR 6
#define KMBOX_VERSION_MINOR 4
#define KMBOX_VERSION_PATCH 0
#define KMBOX_VERSION ((6<<16)|(4<<8)|(0))

#endif
